@@ -55,7 +55,7 @@ class Batch(Workflow, ModelSQL, ModelView):
         #    Bool(('journal', '=', Eval('journal')))
         #    )],
             context={
-                'journal': Eval('journal'),
+                'batch_journal': Eval('journal'),
                 }, states=_states, depends=_depends)
     move_lines = fields.Function(fields.One2Many('account.move.line',
             None, 'Move Lines'), 'get_move_lines')
@@ -154,8 +154,8 @@ class Batch(Workflow, ModelSQL, ModelView):
         if not account:
             return _ZERO
         with Transaction().set_context(no_rounding=True):
-            account = Account(account.id)
-        return account.balance
+            account, = Account.browse([account.id])
+            return account.balance
 
     @classmethod
     def get_journal_type(cls, batches, name):
@@ -233,7 +233,7 @@ class BatchLine(ModelSQL, ModelView):
                 'readonly': Or(
                     Equal(Eval('state'), 'posted'),
                     Bool(Eval('journal', -1)),
-                    Bool(Get(Eval('context', {}), 'journal', 0))
+                    Bool(Get(Eval('context', {}), 'batch_journal', 0))
                     )
             }, depends=['state', 'journal'], select=True)
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscal Year',
@@ -380,7 +380,7 @@ class BatchLine(ModelSQL, ModelView):
         res = copy.copy(res)
         context = Transaction().context
         if res['type'] == 'tree':
-            if context.get('journal'):
+            if context.get('batch_journal'):
                 res['arch'] = res['arch'].replace('<field name="journal"',
                         '<field name="journal" tree_invisible="1"')
             if context.get('batch'):
@@ -411,12 +411,12 @@ class BatchLine(ModelSQL, ModelView):
             if 'batch' in fields:
                 values['batch'] = context['batch']
 
-        if context.get('journal'):
-            journal = BatchJournal(context['journal'])
+        if context.get('batch_journal'):
+            journal = BatchJournal(context['batch_journal'])
             account_journal = journal.account_journal
             side = cls._choose_side(_ZERO, account_journal)
             if 'journal' in fields:
-                values['journal'] = context.get('journal')
+                values['journal'] = context.get('batch_journal')
 
             if 'account' in fields:
                 if journal.account:
@@ -451,7 +451,7 @@ class BatchLine(ModelSQL, ModelView):
             return res
 
         account_journal_id = BatchJournal(
-                context['journal']).account_journal.id
+                context['batch_journal']).account_journal.id
 
         if context.get('period'):
             period = Period(context['period'])
@@ -643,7 +643,7 @@ class BatchLine(ModelSQL, ModelView):
 
         journal = self.journal or self.batch and self.batch.journal
         if not journal:
-            journal_id = Transaction().context.get('journal')
+            journal_id = Transaction().context.get('batch_journal')
             journal = BatchJournal(journal_id)
 
         if self.invoice:
